==> bootstrap-waterfall-0.2.0.tgz: package/CONTRIBUTING.md <==
# Contributing to Bootstrap-waterfall
The codes here is very simple, enjoy your contributing, happy coding!


## Keep it simple
**Simple** is the only one thing to keep in mind.

## Git Commit Messages
* Commit message will be used as release notes directly.  
* Start with an emoji beblow:  

  *(From [Atom](https://github.com/atom/atom/blob/master/CONTRIBUTING.md) Team)*
    * :art: `:art:` when improving the format/structure of the code
    * :racehorse: `:racehorse:` when improving performance
    * :non-potable_water: `:non-potable_water:` when plugging memory leaks
    * :memo: `:memo:` when writing docs
    * :penguin: `:penguin:` when fixing something on Linux
    * :apple: `:apple:` when fixing something on Mac OS
    * :checkered_flag: `:checkered_flag:` when fixing something on Windows
    * :bug: `:bug:` when fixing a bug
    * :fire: `:fire:` when removing code or files
    * :green_heart: `:green_heart:` when fixing the CI build
    * :white_check_mark: `:white_check_mark:` when adding tests
    * :lock: `:lock:` when dealing with security
    * :arrow_up: `:arrow_up:` when upgrading dependencies
    * :arrow_down: `:arrow_down:` when downgrading dependencies
    * :shirt: `:shirt:` when removing linter warnings
  
  *(or)*
    * :beers: `:beers:` when bumping versions
    * :+1: `:+1:` when improving the quality of the code

## Todo
* Prepare gh-pages.
* Write test cases.
* CI

## Done
* Support simple usage.
* Try on [JiaDingWaiMai](https://github.com/Mystist/JiaDingWaiMai).
* Update Yeoman generater.
* Fix the way of getting pin's width when resize with responsive layout.
* Explain why named as bootstrap.

==> bootstrap-waterfall-0.2.1.tgz: package/CONTRIBUTING.md <==
# Contributing to Bootstrap-waterfall
Bootstrap-waterfall is fairly simple, enjoy your contributing, happy coding!


## Keep it simple
**Simple** is the only thing to keep in mind.

## Git Commit Messages
* Commit message will be used as release notes directly.  
* Start with an emoji beblow:  

  *(From [Atom](https://github.com/atom/atom/blob/master/CONTRIBUTING.md) Team)*
    * :art: `:art:` when improving the format/structure of the code
    * :racehorse: `:racehorse:` when improving performance
    * :non-potable_water: `:non-potable_water:` when plugging memory leaks
    * :memo: `:memo:` when writing docs
    * :penguin: `:penguin:` when fixing something on Linux
    * :apple: `:apple:` when fixing something on Mac OS
    * :checkered_flag: `:checkered_flag:` when fixing something on Windows
    * :bug: `:bug:` when fixing a bug
    * :fire: `:fire:` when removing code or files
    * :green_heart: `:green_heart:` when fixing the CI build
    * :white_check_mark: `:white_check_mark:` when adding tests
    * :lock: `:lock:` when dealing with security
    * :arrow_up: `:arrow_up:` when upgrading dependencies
    * :arrow_down: `:arrow_down:` when downgrading dependencies
    * :shirt: `:shirt:` when removing linter warnings
  
  *(or)*
    * :beers: `:beers:` when bumping versions or whenever you want beers!
    * :tada: `:tada:` when none of those above you want to use

## Todo
* Prepare gh-pages.
* Write test cases.
* CI

## Done
* Support simple usage.
* Try on [JiaDingWaiMai](https://github.com/Mystist/JiaDingWaiMai).
* Update Yeoman generater.
* Fix the way of getting pin's width when resize with responsive layout.
* Explain why named as bootstrap.
